FixedWidthDataBlock

Struct FixedWidthDataBlock 

pub struct FixedWidthDataBlock {
    pub data: LanceBuffer,
    pub bits_per_value: u64,
    pub num_values: u64,
    pub block_info: BlockInfo,
}
A data block for a single buffer of data where each element has a fixed number of bits

Fields

data: LanceBuffer

The data buffer

bits_per_value: u64

The number of bits per value

num_values: u64

The number of values represented by this block

block_info: BlockInfo

Implementations

Source

impl FixedWidthDataBlock

pub fn into_arrow( self, data_type: DataType, _validate: bool, ) -> Result<ArrayData>

Convert this block into Arrow data with full layout validation.

The validate argument is retained for API compatibility. Conversion is always validated because callers can construct this public type directly.

pub fn into_buffers(self) -> Vec<LanceBuffer>

pub fn try_clone(&self) -> Result<Self>

pub fn data_size(&self) -> u64