pub struct DecoderConfig {
pub cache_repetition_index: bool,
pub validate_on_decode: bool,
pub inline_scheduling: Option<bool>,
}Expand description
Configuration for decoder behavior
Fields
cache_repetition_index: boolWhether to cache repetition indices for better performance.
This defaults to the LANCE_READ_CACHE_REPETITION_INDEX environment variable
when present and is enabled by default. Set the env var to a non-truthy
value (for example 0 or false) to disable it. The env var is read
once per process.
validate_on_decode: boolWhether to validate decoded data
inline_scheduling: Option<bool>Override the strategy used to dispatch the scheduling work in
schedule_and_decode.
schedule_and_decode always awaits the scheduler’s initialize (which
performs metadata I/O) before returning. This flag controls what
happens with the subsequent (synchronous) work of pushing decoder
messages into the channel that feeds the decode stream.
None- default behavior: the scheduling work runs inline (as part of theschedule_and_decodeawait) when the request is small (controlled by theLANCE_INLINE_SCHEDULING_THRESHOLDenv var) and is dispatched onto a spawned task otherwise.Some(true)- always run scheduling inline. The await ofschedule_and_decodedoes not return until every decoder message has been queued.Some(false)- always spawn a task for scheduling so that it can overlap with consumption of the decode stream.