DecodeArrayTask

Trait DecodeArrayTask 

pub trait DecodeArrayTask: Send {
    // Required method
    fn decode(self: Box<Self>) -> Result<(ArrayRef, u64)>;
}
A trait for tasks that decode data into an Arrow array

Required Methods

fn decode(self: Box<Self>) -> Result<(ArrayRef, u64)>

Decodes the data into an Arrow array and its data size in bytes

Implementations on Foreign Types

Source

impl DecodeArrayTask for Box<dyn StructuralDecodeArrayTask>

Source

fn decode(self: Box<Self>) -> Result<(ArrayRef, u64)>

Implementors