pub struct FieldEncodingContext<'a> {
pub strategy: &'a dyn FieldEncodingStrategy,
pub options: &'a EncodingOptions,
pub root_field_metadata: &'a HashMap<String, String>,
}Expand description
Context shared while one top-level field and all of its children are mapped to concrete field encoders.
Fields
strategy: &'a dyn FieldEncodingStrategyThe complete strategy composition used for recursive child fields.
options: &'a EncodingOptionsRuntime-only writer options.
root_field_metadata: &'a HashMap<String, String>Metadata inherited from the top-level field.