Module structural

Module structural 

Version-free structural field encoder builders.

Re-exports

pub use crate::encodings::logical::primitive::PrimitivePageEncoding;

Structs

PrimitiveFieldEncoding
Encode primitive leaves, primitive fixed-size lists, dictionaries, and packed or empty structs using one concrete primitive page grammar.

Functions

try_create_binary_blob
Create the original binary blob descriptor when field matches.
try_create_list
Create a variable-size list encoder when field matches.
try_create_map
Create an Arrow map encoder when field matches.
try_create_struct
Create a non-packed, non-empty struct encoder when field matches.
try_create_structural_blob
Create the structural blob descriptor when field matches.
try_create_structural_fixed_size_list
Create a fixed-size-list encoder whose child is a struct when applicable.