pub struct PrimitiveFieldEncoding { /* private fields */ }Expand description
Encode primitive leaves, primitive fixed-size lists, dictionaries, and packed or empty structs using one concrete primitive page grammar.
Implementations
Sourceimpl PrimitiveFieldEncoding
impl PrimitiveFieldEncoding
Sourcepub fn new(
page_encodings: impl IntoIterator<Item = PrimitivePageEncoding>,
) -> Self
pub fn new( page_encodings: impl IntoIterator<Item = PrimitivePageEncoding>, ) -> Self
Create a primitive field mechanism from ordered executable page behaviors.
Sourcepub fn try_create(
&self,
field: &Field,
column_index: &mut ColumnIndexSequence,
context: &FieldEncodingContext<'_>,
) -> Result<Option<Box<dyn FieldEncoder>>>
pub fn try_create( &self, field: &Field, column_index: &mut ColumnIndexSequence, context: &FieldEncodingContext<'_>, ) -> Result<Option<Box<dyn FieldEncoder>>>
Create a primitive field encoder when this mechanism recognizes field.