pub struct StructuralPrimitiveFieldScheduler { /* private fields */ }Expand description
A scheduler for a leaf node
Here we look at the layout of the various pages and delegate scheduling to a scheduler appropriate for the layout of the page.
Implementations
Sourceimpl StructuralPrimitiveFieldScheduler
impl StructuralPrimitiveFieldScheduler
pub fn try_new( column_info: &ColumnInfo, decompressors: &dyn DecompressionStrategy, cache_repetition_index: bool, target_field: &Field, ) -> Result<Self>