Module general

Module general 

Structs

GeneralMiniBlockCompressor
A miniblock compressor that wraps another miniblock compressor and applies general-purpose compression (LZ4, Zstd) to the resulting buffers.
GeneralMiniBlockDecompressor
A miniblock decompressor that first decompresses buffers using general-purpose compression (LZ4, Zstd) and then delegates to an inner miniblock decompressor.