pub enum Counts {
Explicit(CompressiveEncoding),
Constant(SparseCountConstant),
Empty(SparseCountEmpty),
}Variants
Explicit(CompressiveEncoding)
Compressed u64 child counts. Cardinality comes from the containing position set.
Constant(SparseCountConstant)
One positive child count shared by every non-empty list slot.
Empty(SparseCountEmpty)
No counts; valid only when there are no non-empty list slots.
Implementations
Sourceimpl Counts
impl Counts
Sourcepub fn merge(
field: &mut Option<Counts>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Counts>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.