pub enum Positions {
Explicit(CompressiveEncoding),
Range(SparsePositionRange),
All(SparsePositionAll),
Empty(SparsePositionEmpty),
}Variants
Explicit(CompressiveEncoding)
Delta-compressed u64 positions. Cardinality is num_positions.
Range(SparsePositionRange)
One contiguous, non-empty range.
All(SparsePositionAll)
Every position in the domain.
Empty(SparsePositionEmpty)
No positions in the domain.
Implementations
Sourceimpl Positions
impl Positions
Sourcepub fn merge(
field: &mut Option<Positions>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Positions>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.