#[repr(i32)]pub enum Meaning {
SparseValidityUnspecified = 0,
SparseValidityNullPositions = 1,
SparseValidityValidPositions = 2,
}Variants
SparseValidityUnspecified = 0
SparseValidityNullPositions = 1
Stored positions are null; all other positions are valid.
SparseValidityValidPositions = 2
Stored positions are valid; all other positions are null.
Implementations
Sourceimpl Meaning
impl Meaning
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.