pub struct ConstantLayout {
pub layers: Vec<i32>,
pub inline_value: Option<Bytes>,
pub rep_compression: Option<CompressiveEncoding>,
pub def_compression: Option<CompressiveEncoding>,
pub num_rep_values: u64,
pub num_def_values: u64,
}Expand description
A layout used for pages where all (visible) values are the same scalar value.
This generalizes the prior AllNullLayout semantics for file_version >= 2.2.
There may be buffers of repetition and definition information if required in order to interpret what kind of nulls are present / which items are visible.
Fields
layers: Vec<i32>The meaning of each repdef layer, used to interpret repdef buffers correctly
inline_value: Option<Bytes>Inline fixed-width scalar value bytes.
This MUST only be used for types where a single non-null element is represented by a single fixed-width Arrow value buffer (i.e. no offsets buffer, no child data).
Constraints:
- MUST be absent for an all-null page
- MUST be <= 32 bytes if present
rep_compression: Option<CompressiveEncoding>Optional compression algorithm used for the repetition buffer. If absent, repetition levels are stored as raw u16 values.
def_compression: Option<CompressiveEncoding>Optional compression algorithm used for the definition buffer. If absent, definition levels are stored as raw u16 values.
num_rep_values: u64Number of values in repetition buffer after decompression.
num_def_values: u64Number of values in definition buffer after decompression.
Implementations
Sourceimpl ConstantLayout
impl ConstantLayout
Sourcepub fn layers(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<RepDefLayer>>
pub fn layers( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<RepDefLayer>>
Returns an iterator which yields the valid enum values contained in layers.
Sourcepub fn push_layers(&mut self, value: RepDefLayer)
pub fn push_layers(&mut self, value: RepDefLayer)
Appends the provided enum value to layers.
Sourcepub fn inline_value(&self) -> &[u8] ⓘ
pub fn inline_value(&self) -> &[u8] ⓘ
Returns the value of inline_value, or the default value if inline_value is unset.