Version-free structural field encoder builders.
Re-exports
pub use crate::encodings::logical::primitive::PrimitivePageEncoding;
Structs
- Primitive
Field Encoding - Encode primitive leaves, primitive fixed-size lists, dictionaries, and packed or empty structs using one concrete primitive page grammar.
Functions
- try_
create_ binary_ blob - Create the original binary blob descriptor when
fieldmatches. - try_
create_ list - Create a variable-size list encoder when
fieldmatches. - try_
create_ map - Create an Arrow map encoder when
fieldmatches. - try_
create_ struct - Create a non-packed, non-empty struct encoder when
fieldmatches. - try_
create_ structural_ blob - Create the structural blob descriptor when
fieldmatches. - try_
create_ structural_ fixed_ size_ list - Create a fixed-size-list encoder whose child is a struct when applicable.