Structs
- General
Mini Block Compressor - A miniblock compressor that wraps another miniblock compressor and applies general-purpose compression (LZ4, Zstd) to the resulting buffers.
- General
Mini Block Decompressor - A miniblock decompressor that first decompresses buffers using general-purpose compression (LZ4, Zstd) and then delegates to an inner miniblock decompressor.